@@ -1,21 +1,7 @@
 /*
- *   Copyright 2017, 2018, 2019 by Ivan Cukic <ivan.cukic (at) kde.org>
+ *   SPDX-FileCopyrightText: 2017, 2018, 2019 Ivan Cukic <ivan.cukic (at) kde.org>
  *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License or (at your option) version 3 or any later version
- *   accepted by the membership of KDE e.V. (or its successor approved
- *   by the membership of KDE e.V.), which shall act as a proxy
- *   defined in Section 14 of version 3 of the license.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #ifndef PLASMAVAULT_KDED_SERVICE_H
@@ -28,12 +14,13 @@
 #include <common/vaultinfo.h>
 #include <engine/vault.h>
 
-class Q_DECL_EXPORT PlasmaVaultService : public KDEDModule {
+class Q_DECL_EXPORT PlasmaVaultService : public KDEDModule
+{
     Q_CLASSINFO("D-Bus Interface", "org.kde.plasmavault")
     Q_OBJECT
 
 public:
-    PlasmaVaultService(QObject *parent, const QVariantList&);
+    PlasmaVaultService(QObject *parent, const QVariantList &);
     ~PlasmaVaultService();
 
 public Q_SLOTS:
@@ -82,7 +69,6 @@ private Q_SLOTS:
 private:
     class Private;
     QScopedPointer<Private> d;
-
 };
 
 #endif // include guard
